/// <reference types="node" />
import { Canvas, CanvasRenderingContext2D } from "canvas";
import { CanvasImage, CustomColor, ImageExtention, Shape, ImagelocationOption, DrawlocationOption, ExpOption, FrameOption, TextOption, FrameContent, FrameType, LoadingOption, ShapeLoad, Axis, IntRange } from "..";
import { ExpColor } from "../Interfaces";
export default class NessBuilder {
    protected canvas: Canvas;
    context: CanvasRenderingContext2D;
    private canvasSize;
    private axis;
    private frameCoordinate;
    private frameTextCoordinate;
    private fontData;
    private loadingDirection;
    constructor(width: number, height: number);
    /**
     * New Canvas Dimension
     *
     * @param width x-dimension in pixels
     * @param height y-dimension in pixels
     */
    private setCanvas;
    /**
     * Special image background
     * @param color CustomColor<CanvasGradient | CanvasPattern>
     */
    private customBackground;
    /**
     * canvas outline radius
     *
     * @param radius The radius to set
     * @param outline Line size (default 3)
     * @param color Line color (default #FFFFFF)
     */
    setCornerRadius(radius: number, outline?: number, color?: CustomColor): this;
    /**
     * Sets the canvas background.
     * @param imageColor The image to set (no link, use loadImage() from canvas) or a custom color (Valid syntaxes: #hex | rgb | rgba | colorName | CanvasGradient | CanvasPattern)
     */
    setBackground(imageColor: CanvasImage | CustomColor): this;
    /**
     * Draw an image to S coordinates with D dimensions
     *
     * @param image The image to set (no link, use loadImage() from canvas)
     * @param imageOption Source image coordinates to draw in the context of Canvas
     * @param locationOption Modify image coordinates to draw in the context of Canvas
     */
    setImage(image: CanvasImage, imageOption: ImagelocationOption, locationOption?: DrawlocationOption): this;
    /**
     * Sets a predefined frame
     *
     * @param typeShape Frame format
     * @param coordinate Coordinate X and Y from upper left corner of the frame
     * @param size Frame size
     * @param options Frame configuration
     */
    setFrame<T extends FrameType, S extends Shape>(shape: S, frame: FrameOption<S>, options: FrameContent<T>): this;
    private setShape;
    private setRotation;
    private setFrameBackground;
    /**
     * Set text to canvas
     *
     * @param text Text to write
     * @param coordinate Text location
     * @param option Text option
     */
    setText(text: string, coordinate: {
        x: number;
        y: number;
    }, option: TextOption): this;
    /**
     * Change font to use
     *
     * @param name Add * to use the system font (*Arial) or CustomFont (RegisterFont)
     * @param size Font size
     */
    setFont(name: string, size?: number): this;
    private getFont;
    /**
     * register a new font
     *
     * @param path Path to font file (file.ttf)
     * @param option Font default settings
     */
    private registerFont;
    private restore;
    /**
     * Set progress bar
     *
     * @param location Coordinate to set ExpBar
     * @param size Size of the first progression bar
     * @param radius Radius to set
     * @param progress Progression of the second progression bar 0 - 100%
     * @param color Text color. White color is used by Default
     */
    setExp(option: ExpOption, progress: IntRange<0, 101>, color?: ExpColor): this;
    setLoading<D extends ShapeLoad, S extends Shape>(shape: Shape, option: LoadingOption<D, S>): this;
    private setLoadingDirection;
    setAxis(axis: Axis): this;
    private getAxis;
    /**
     * Return canvas Buffer
     */
    toBuffer(ext?: ImageExtention | "raw" | "pdf"): Buffer;
    /**
     * Generated image from canvas
     *
     * @param location Image Generation Path
     * @param name Image name
     * @param type Image extention
     */
    generatedTo(location: string, name: string, type: ImageExtention): void;
    /**
     * Returns a base64 encoded string
     */
    toDataURL(): string;
}
//# sourceMappingURL=NessBuilder.d.ts.map